@@ -1,7 +1,8 @@
 
 package Chart;
-our $VERSION = 2.400.5;
+our $VERSION = 2.400.6;
 
+1;
 
 $VERSION = Chart;
 =pod
@@ -697,7 +698,6 @@ The cgi_png method will print the chart, along with the appropriate http
 header, to stdout, allowing you to call chart-generating scripts directly
 from your html pages (ie. with a <lt>img src=image.pl<gt> HTML tag). 
 
-=back
 
 =item Produce a png image as a scalar
 
@@ -707,8 +707,6 @@ s/he wants to with it:
 
   	$obj-scalar_png($dataref)
 
-=back
-
 
 
 =item Produce a jpeg image as a scalar
@@ -765,9 +763,12 @@ since that's the place in the @data array for the data point labels.
 
 Add some 3-D graphs.
 Include True Type Fonts
+Violine and Box plots
 
 =back
 
+For elaborate plans look into the L<TODO|../TODO>.
+
 =head1 BUGS
 
 Probably quite a few, since it's been completely rewritten.  As usual,
@@ -781,6 +782,7 @@ David Bonner (dbonner@cs.bu.edu)
 =head1 MAINTAINER
 
 Chart Group (Chart@fs.wettzell.de)
+Herbert Breunung (lichtkind@cpan.org)
 
 =head1 COPYRIGHT
 
